Enum diem_framework_releases::legacy::transaction_scripts::LegacyStdlibScript [−][src]
pub enum LegacyStdlibScript {
Show 33 variants
AddCurrencyToAccount,
AddRecoveryRotationCapability,
AddValidatorAndReconfigure,
Burn,
BurnTxnFees,
CancelBurn,
CreateChildVaspAccount,
CreateDesignatedDealer,
CreateParentVaspAccount,
CreateRecoveryAddress,
CreateValidatorAccount,
CreateValidatorOperatorAccount,
FreezeAccount,
PeerToPeerWithMetadata,
Preburn,
PublishSharedEd2551PublicKey,
RegisterValidatorConfig,
RemoveValidatorAndReconfigure,
RotateAuthenticationKey,
RotateAuthenticationKeyWithNonce,
RotateAuthenticationKeyWithNonceAdmin,
RotateAuthenticationKeyWithRecoveryAddress,
RotateDualAttestationInfo,
RotateSharedEd2551PublicKey,
SetValidatorConfigAndReconfigure,
SetValidatorOperator,
SetValidatorOperatorWithNonceAdmin,
TieredMint,
UnfreezeAccount,
UpdateExchangeRate,
UpdateDiemVersion,
UpdateMintingAbility,
UpdateDualAttestationLimit,
}Expand description
All of the Move transaction scripts that can be executed on the Diem blockchain
Variants
Implementations
Return a vector containing all of the standard library scripts (i.e., all inhabitants of the StdlibScript enum)
Construct the allowlist of script hashes used to determine whether a transaction script can be executed on the Diem blockchain
Return true if code_bytes is the bytecode of one of the standard library scripts
Return the Move bytecode that was produced by compiling this script.
Return the ABI of the script (including the bytecode).
NB: For legacy scripts, the script ABI will always be a TransactionScriptABI.